# Kodi - Voice

Python package to make interfacing with Kodi very easy, especially when dealing with VUI like Amazon Echo, Google Home, and Cortana. But it could be used to control just about anything on a Kodi box.

## Install
`pip install kodi-voice`

## Configure
Configuration works off of a configuration file named `kodi.config`. If it can't find this file, it will try to read some environment variables to set defaults.